![Logo](https://github.com/0xnenlabs/SageAI/assets/45445790/750fb3f9-0830-4948-9a86-61e59d933b45)

<p align="center">
    <em>File-based functions for ChatGPT's function calling with Pydantic support 🚀</em>
</p>

<p align="center">
<a href="https://github.com/yezz123/ormdantic/actions/workflows/ci.yml" target="_blank">
    <img src="https://github.com/yezz123/ormdantic/actions/workflows/ci.yml/badge.svg" alt="Test">
</a>
<a href="https://codecov.io/gh/yezz123/ormdantic">
    <img src="https://codecov.io/gh/yezz123/ormdantic/branch/main/graph/badge.svg"/>
</a>
<a href="https://pypi.org/project/sageai" target="_blank">
    <img src="https://img.shields.io/pypi/v/sageai?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://pypi.org/project/sageai" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/sageai.svg?color=%2334D058" alt="Supported Python versions">
</a>
</p>

SageAI is a lightweight package that

## Key Features

- File-based functions directory for OpenAI function calls
- Functions typed with Pydantic (v1 only)
- In memory Vector DB to reduce costs (not all functions get passed in as context)
- Supports asyncio/sync
- Easily testable (both unit and integration)
- Extensible (bring your own vector db + implementation)
- Lightweight

## Requirements

Pass

## Installation

```bash
# pip
$ pip install sageai

# poetry
$ poetry add sageai
```

## Usage

Pass

## Contributing

Please see our [CONTRIBUTING.md](/CONTRIBUTING.md).
